@@ -1,11 +1,11 @@
 # Human friendly input/output in Python.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: November 15, 2014
+# Last Change: November 16, 2014
 # URL: https://humanfriendly.readthedocs.org
 
 # Semi-standard module versioning.
-__version__ = '1.11'
+__version__ = '1.13'
 
 # Standard library modules.
 import math
@@ -187,8 +187,7 @@ def format_timespan(num_seconds):
     """
     if num_seconds < 60:
         # Fast path.
-        rounded_number = round_number(num_seconds, num_seconds < 10)
-        return pluralize(rounded_number, 'second')
+        return pluralize(round_number(num_seconds), 'second')
     else:
         # Slow path.
         result = []
@@ -423,6 +422,11 @@ class Timer(object):
             elapsed_time += time.time() - self.start_time
         return elapsed_time
 
+    @property
+    def rounded(self):
+        """Human readable timespan rounded to seconds (a string)."""
+        return format_timespan(round(self.elapsed_time))
+
     def __str__(self):
         """
         When a :py:class:`Timer` is coerced to a string it will show the
@@ -450,7 +454,7 @@ class Spinner(object):
     | Downloading: 1.00% # travels up to 100%...
     """
 
-    def __init__(self, label=None, total=0, stream=sys.stderr, interactive=None):
+    def __init__(self, label=None, total=0, stream=sys.stderr, interactive=None, timer=None):
         """
         Initialize a spinner.
 
@@ -461,6 +465,9 @@ class Spinner(object):
         :param interactive: If this is ``False`` then the spinner doesn't write
                             to the output stream at all. It defaults to the
                             return value of ``stream.isatty()``.
+        :param timer: A :py:class:`Timer` object (optional). If this is given
+                      the spinner will show the elapsed time according to the
+                      timer.
         """
         self.label = label
         self.total = total
@@ -474,6 +481,7 @@ class Spinner(object):
             except Exception:
                 interactive = False
         self.interactive = interactive
+        self.timer = timer
 
     def step(self, progress=0, label=None):
         """
@@ -493,7 +501,9 @@ class Spinner(object):
                     raise Exception("No label set for spinner!")
                 elif self.total and progress:
                     label = "%s: %.2f%%" % (label, progress/(self.total/100.0))
-                self.stream.write("\r %s %s " % (state, label))
+                elif self.timer and self.timer.elapsed_time > 2:
+                    label = "%s (%s)" % (label, self.timer.rounded)
+                self.stream.write("\r %s %s .. " % (state, label))
                 self.counter += 1
 
     def clear(self):
